Documentation
¶
Overview ¶
Package api is the internal version of the API.
Index ¶
Constants ¶
const ( FlunderReferenceType = ReferenceType("Flunder") FischerReferenceType = ReferenceType("Fischer") )
const GroupName = "wardle.k8s.io"
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns back a Group qualified GroupResource
Types ¶
type Fischer ¶
type Fischer struct {
metav1.TypeMeta
metav1.ObjectMeta
// DisallowedFlunders holds a list of Flunder.Names that are disallowed.
DisallowedFlunders []string
}
func (*Fischer) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Fischer.
func (*Fischer) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Fischer) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FischerList ¶
type FischerList struct {
metav1.TypeMeta
metav1.ListMeta
// Items is a list of Fischers
Items []Fischer
}
FischerList is a list of Fischer objects.
func (*FischerList) DeepCopy ¶
func (in *FischerList) DeepCopy() *FischerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FischerList.
func (*FischerList) DeepCopyInto ¶
func (in *FischerList) DeepCopyInto(out *FischerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FischerList) DeepCopyObject ¶
func (in *FischerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type Flunder ¶
type Flunder struct {
metav1.TypeMeta
metav1.ObjectMeta
Spec FlunderSpec
Status FlunderStatus
}
func (*Flunder) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Flunder.
func (*Flunder) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Flunder) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FlunderList ¶
FlunderList is a list of Flunder objects.
func (*FlunderList) DeepCopy ¶
func (in *FlunderList) DeepCopy() *FlunderList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlunderList.
func (*FlunderList) DeepCopyInto ¶
func (in *FlunderList) DeepCopyInto(out *FlunderList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FlunderList) DeepCopyObject ¶
func (in *FlunderList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FlunderSpec ¶
type FlunderSpec struct {
// A name of another flunder, mutually exclusive to the FischerReference.
FlunderReference string
// A name of a fischer, mutually exclusive to the FlunderReference.
FischerReference string
// The reference type.
ReferenceType ReferenceType
}
func (*FlunderSpec) DeepCopy ¶
func (in *FlunderSpec) DeepCopy() *FlunderSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlunderSpec.
func (*FlunderSpec) DeepCopyInto ¶
func (in *FlunderSpec) DeepCopyInto(out *FlunderSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlunderStatus ¶
type FlunderStatus struct {
}
func (*FlunderStatus) DeepCopy ¶
func (in *FlunderStatus) DeepCopy() *FlunderStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlunderStatus.
func (*FlunderStatus) DeepCopyInto ¶
func (in *FlunderStatus) DeepCopyInto(out *FlunderStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReferenceType ¶
type ReferenceType string