Documentation
¶
Index ¶
- func NewFilteredFischerInformer(client clientsetinternalversion.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredFlunderInformer(client clientsetinternalversion.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFischerInformer(client clientsetinternalversion.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFlunderInformer(client clientsetinternalversion.Interface, namespace string, ...) cache.SharedIndexInformer
- type FischerInformer
- type FlunderInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredFischerInformer ¶
func NewFilteredFischerInformer(client clientsetinternalversion.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredFischerInformer constructs a new informer for Fischer type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredFlunderInformer ¶
func NewFilteredFlunderInformer(client clientsetinternalversion.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredFlunderInformer constructs a new informer for Flunder type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFischerInformer ¶
func NewFischerInformer(client clientsetinternalversion.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewFischerInformer constructs a new informer for Fischer type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFlunderInformer ¶
func NewFlunderInformer(client clientsetinternalversion.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewFlunderInformer constructs a new informer for Flunder type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type FischerInformer ¶
type FischerInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.FischerLister
}
FischerInformer provides access to a shared informer and lister for Fischers.
type FlunderInformer ¶
type FlunderInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.FlunderLister
}
FlunderInformer provides access to a shared informer and lister for Flunders.
type Interface ¶
type Interface interface {
// Fischers returns a FischerInformer.
Fischers() FischerInformer
// Flunders returns a FlunderInformer.
Flunders() FlunderInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.